@@ -1,9 +1,9 @@
 # app/prompts/sample_prompt.py
-from mcp.server.fastmcp import FastMCP
-import mcp.types as types
+from fastmcp import FastMCP
+from viyv_mcp import prompt
 
 def register(mcp: FastMCP):
-    @mcp.prompt()
+    @prompt()
     def sample_prompt(query: str) -> str:
         """
         ユーザーの質問に対して、そのまま返すプロンプトの例。
