@@ -1,8 +1,9 @@
 # app/resources/sample_echo_resource.py
-from mcp.server.fastmcp import FastMCP
+from fastmcp import FastMCP
+from viyv_mcp import resource
 
 def register(mcp: FastMCP):
-    @mcp.resource("echo://{message}")
+    @resource("echo://{message}")
     def echo_resource(message: str) -> str:
         """入力されたメッセージをそのまま返すリソース"""
         return f"Echo: {message}"
\ No newline at end of file
